@@ -201,27 +201,19 @@ spawn_command(GtkWidget * widget, const gchar * command)
 gboolean
 update_time(GtkWidget * label)
 {
-    gchar *timestring = 0;
     time_t timet;
     struct tm *timePtr;
+    gchar *clock_format;
+    gchar label_markup[100];
 
     timet = time(NULL);
     timePtr = localtime(&timet);
 
-    // use 12 hour clock format if LDM_12HOURCLOCK is set to true
-    if (ldm_getenv_bool("LDM_12HOURCLOCK")) {
-        timestring = g_strdup_printf("<b>%.2d:%.2d</b>",
-                                     (timePtr->tm_hour %
-                                      12) ? (timePtr->tm_hour % 12) : 12,
-                                     timePtr->tm_min);
-    } else {
-        timestring = g_strdup_printf("<b>%.2d:%.2d</b>",
-                                     timePtr->tm_hour, timePtr->tm_min);
-    }
-
-    gtk_label_set_markup((GtkLabel *) label, timestring);
-
-    g_free(timestring);
+    // Allow the users to customize the clock format including the GTK markup,
+    // for example in case they want the date non-bold and the time in bold.
+    clock_format=ldm_getenv_str_default("LDM_CLOCK_FORMAT", "%x, <b>%H:%M</b>");
+    if (strftime(label_markup, sizeof(label_markup), clock_format, timePtr))
+        gtk_label_set_markup((GtkLabel *) label, label_markup);
 
     return TRUE;
 }
@@ -705,7 +697,7 @@ main(int argc, char *argv[])
                             getenv("LDMINFO_IPADDR"));
 #else
         hoststring =
-            g_strdup_printf("<b>%s</b> (%s) //", get_sysname(),
+            g_strdup_printf("<b>%s</b> (%s) -", get_sysname(),
                             getenv("LDMINFO_IPADDR"));
 #endif
         gtk_label_set_markup((GtkLabel *) syslabel, hoststring);
